==> zio-aws-schemas_2.13-5.17.124.3-sources.jar: zio/aws/schemas/model/package.scala <==
package zio.aws.schemas
import zio.prelude.Subtype
import zio.Chunk
import java.time.Instant
import zio.aws.schemas.model.primitives.{
  GetDiscoveredSchemaVersionItemInput,
  __string
}
package object model {
  import scala.jdk.CollectionConverters._
  object primitives {
    object Body extends Subtype[Chunk[Byte]]
    type Body = zio.aws.schemas.model.primitives.Body.Type
    object GetDiscoveredSchemaVersionItemInput extends Subtype[String]
    type GetDiscoveredSchemaVersionItemInput =
      zio.aws.schemas.model.primitives.GetDiscoveredSchemaVersionItemInput.Type
    object __boolean extends Subtype[Boolean]
    type __boolean = zio.aws.schemas.model.primitives.__boolean.Type
    object __integer extends Subtype[Int]
    type __integer = zio.aws.schemas.model.primitives.__integer.Type
    object __long extends Subtype[Long]
    type __long = zio.aws.schemas.model.primitives.__long.Type
    object __string extends Subtype[String]
    type __string = zio.aws.schemas.model.primitives.__string.Type
    object __stringMin0Max256 extends Subtype[String]
    type __stringMin0Max256 =
      zio.aws.schemas.model.primitives.__stringMin0Max256.Type
    object __stringMin0Max36 extends Subtype[String]
    type __stringMin0Max36 =
      zio.aws.schemas.model.primitives.__stringMin0Max36.Type
    object __stringMin1Max100000 extends Subtype[String]
    type __stringMin1Max100000 =
      zio.aws.schemas.model.primitives.__stringMin1Max100000.Type
    object __stringMin20Max1600 extends Subtype[String]
    type __stringMin20Max1600 =
      zio.aws.schemas.model.primitives.__stringMin20Max1600.Type
    object __timestampIso8601 extends Subtype[Instant]
    type __timestampIso8601 =
      zio.aws.schemas.model.primitives.__timestampIso8601.Type
  }
  type Tags = Map[__string, __string]
  type __listOfDiscovererSummary = List[zio.aws.schemas.model.DiscovererSummary]
  type __listOfGetDiscoveredSchemaVersionItemInput =
    List[GetDiscoveredSchemaVersionItemInput]
  type __listOfRegistrySummary = List[zio.aws.schemas.model.RegistrySummary]
  type __listOfSchemaSummary = List[zio.aws.schemas.model.SchemaSummary]
  type __listOfSchemaVersionSummary =
    List[zio.aws.schemas.model.SchemaVersionSummary]
  type __listOfSearchSchemaSummary =
    List[zio.aws.schemas.model.SearchSchemaSummary]
  type __listOfSearchSchemaVersionSummary =
    List[zio.aws.schemas.model.SearchSchemaVersionSummary]
  type __listOf__string = List[__string]
}

==> zio-aws-schemas_2.13-6.20.58.2-sources.jar: zio/aws/schemas/model/package.scala <==
package zio.aws.schemas
import zio.prelude.Subtype
import zio.Chunk
import java.time.Instant
import zio.aws.schemas.model.primitives.{
  GetDiscoveredSchemaVersionItemInput,
  __string
}
package object model {
  import scala.jdk.CollectionConverters._
  object primitives {
    object Body extends Subtype[Chunk[Byte]]
    type Body = zio.aws.schemas.model.primitives.Body.Type
    object GetDiscoveredSchemaVersionItemInput extends Subtype[String]
    type GetDiscoveredSchemaVersionItemInput =
      zio.aws.schemas.model.primitives.GetDiscoveredSchemaVersionItemInput.Type
    type __boolean = Boolean
    type __integer = Int
    type __long = Long
    type __string = String
    type __stringMin0Max256 = String
    type __stringMin0Max36 = String
    type __stringMin1Max100000 = String
    type __stringMin20Max1600 = String
    type __timestampIso8601 = Instant
  }
  type Tags = Map[__string, __string]
  type __listOfDiscovererSummary = List[zio.aws.schemas.model.DiscovererSummary]
  type __listOfGetDiscoveredSchemaVersionItemInput =
    List[GetDiscoveredSchemaVersionItemInput]
  type __listOfRegistrySummary = List[zio.aws.schemas.model.RegistrySummary]
  type __listOfSchemaSummary = List[zio.aws.schemas.model.SchemaSummary]
  type __listOfSchemaVersionSummary =
    List[zio.aws.schemas.model.SchemaVersionSummary]
  type __listOfSearchSchemaSummary =
    List[zio.aws.schemas.model.SearchSchemaSummary]
  type __listOfSearchSchemaVersionSummary =
    List[zio.aws.schemas.model.SearchSchemaVersionSummary]
  type __listOf__string = List[__string]
}
